SessionProposalErrorEvent class

Inheritance

Constructors

SessionProposalErrorEvent(int id, Map<String, RequiredNamespace> requiredNamespaces, Map<String, Namespace> namespaces, ReownSignError error)

Properties

error ↔ ReownSignError
getter/setter pair
eventName ↔ String?
The name of associated Event. Default value is null. Typically set by external code.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
namespaces ↔ Map<String, Namespace>
getter/setter pair
requiredNamespaces ↔ Map<String, RequiredNamespace>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
whenOccurred ↔ DateTime?
The date/time when the event is broadcast. Until broadcast, the value is null.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited